@@ -6,7 +6,7 @@ use List::Util qw( first );
 use Path::Tiny qw( path );
 
 # ABSTRACT: Use Alien::Build with Dist::Zilla
-our $VERSION = '0.18'; # VERSION
+our $VERSION = '0.19'; # VERSION
 
 
 with 'Dist::Zilla::Role::FileMunger';
@@ -53,14 +53,9 @@ sub register_prereqs
 
     my $ab_version = '0.32';
 
-    foreach my $hook (qw( build_ffi gather_ffi ))
+    foreach my $hook (qw( build_ffi gather_ffi patch_ffi ))
     {
-      $ab_version = '0.38';
-    }
-
-    foreach my $hook (qw( patch_ffi ))
-    {
-      $ab_version = '0.39';
+      $ab_version = '0.40';
     }
 
     if($self->_installer eq 'Makefile.PL')
@@ -182,7 +177,7 @@ Dist::Zilla::Plugin::AlienBuild - Use Alien::Build with Dist::Zilla
 
 =head1 VERSION
 
-version 0.18
+version 0.19
 
 =head1 SYNOPSIS
 
